mathtools.Infinity
==================

.. abjad-lineage:: abjad.tools.mathtools.Infinity.Infinity

.. autoclass:: abjad.tools.mathtools.Infinity.Infinity

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.mathtools.Infinity.Infinity.__eq__
      ~abjad.tools.mathtools.Infinity.Infinity.__format__
      ~abjad.tools.mathtools.Infinity.Infinity.__ge__
      ~abjad.tools.mathtools.Infinity.Infinity.__gt__
      ~abjad.tools.mathtools.Infinity.Infinity.__le__
      ~abjad.tools.mathtools.Infinity.Infinity.__lt__
      ~abjad.tools.mathtools.Infinity.Infinity.__ne__
      ~abjad.tools.mathtools.Infinity.Infinity.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Special methods
---------------

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.__eq__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.__format__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.__ge__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.__gt__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.__le__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.__lt__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.__ne__
   :noindex:

.. automethod:: abjad.tools.mathtools.Infinity.Infinity.__repr__
   :noindex:
